==> TencentMapSDK_iOS_3D_v6.5.0.zip: html/protocol_q_map_view_delegate-p.js <==
var protocol_q_map_view_delegate_p =
[
    [ "locationManagerDidChangeAuthorization:", "protocol_q_map_view_delegate-p.html#ae05ae20c1c451ae46bbf17c1fa041bad", null ],
    [ "mapUpdateFinished:", "protocol_q_map_view_delegate-p.html#ada2dcef0bc352b7a08c0c016174e647a", null ],
    [ "mapView:annotationView:calloutAccessoryControlTapped:", "protocol_q_map_view_delegate-p.html#addc6778f9d1536b431066d14184dd3ee", null ],
    [ "mapView:annotationView:collidedViewsDidHide:", "protocol_q_map_view_delegate-p.html#a154869a9351385b58c38802c07923cd5", null ],
    [ "mapView:annotationView:collidedViewsDidShow:", "protocol_q_map_view_delegate-p.html#ad50638743d3e7dd71db4e4ed4cf3c773", null ],
    [ "mapView:annotationView:didChangeDragState:fromOldState:", "protocol_q_map_view_delegate-p.html#a9ee4627234450c4a728af6216cddca9b", null ],
    [ "mapView:annotationViewCalloutTapped:", "protocol_q_map_view_delegate-p.html#a04e22a4d9bd72c10e8c6f3be1440cd7c", null ],
    [ "mapView:customCalloutForAnnotationView:", "protocol_q_map_view_delegate-p.html#af1ad6c0ad59e863c65a9c3e037ea60f4", null ],
    [ "mapView:didAddAnnotationViews:", "protocol_q_map_view_delegate-p.html#ad23a7ea97bde36822c7a1633ccd68e26", null ],
    [ "mapView:didAddOverlayViews:", "protocol_q_map_view_delegate-p.html#a80f0a2693fb0c8edced25805037f13bd", null ],
    [ "mapView:didAnnotationViewTapped:", "protocol_q_map_view_delegate-p.html#abe7ad61a355ba6abe7b70156bdbb1a41", null ],
    [ "mapView:didChangeUserTrackingMode:animated:", "protocol_q_map_view_delegate-p.html#a187da22432616cb02f4c074c21f4f2a8", null ],
    [ "mapView:didDeselectAnnotationView:", "protocol_q_map_view_delegate-p.html#ad500838cdd3f744fa393a7cc3c69bd9d", null ],
    [ "mapView:didFailToLocateUserWithError:", "protocol_q_map_view_delegate-p.html#aaf54cbaa96411ed613553a316e4f30ae", null ],
    [ "mapView:didMoveAnimated:gesture:", "protocol_q_map_view_delegate-p.html#a084ca8d89c79d8dbb0536ad148d63662", null ],
    [ "mapView:didSelectAnnotationView:", "protocol_q_map_view_delegate-p.html#a62fdf8aa5a7aef763b125c998eaf8964", null ],
    [ "mapView:didTapAtCoordinate:", "protocol_q_map_view_delegate-p.html#a980880cd3da3156540ba0a69855ce477", null ],
    [ "mapView:didTapMarkerOverlayCallout:", "protocol_q_map_view_delegate-p.html#acfd18e33e5bc42997b987693a2468fa3", null ],
    [ "mapView:didTapMyLocation:", "protocol_q_map_view_delegate-p.html#a5ba6df7eef363f7d31b036e167d2aec1", null ],
    [ "mapView:didTapOverlay:", "protocol_q_map_view_delegate-p.html#a3a5e63eb5525ca332ab13d50c545ed1d", null ],
    [ "mapView:didTapOverlay:coordinate:", "protocol_q_map_view_delegate-p.html#ac48a37ffc5259cece81e03cd94199092", null ],
    [ "mapView:didTapPoi:", "protocol_q_map_view_delegate-p.html#a6fa4fcb119acfb63b82f12d94d921d31", null ],
    [ "mapView:didUpdateUserLocation:fromHeading:", "protocol_q_map_view_delegate-p.html#a2727ba05ddc465b2bf8dda886b99a960", null ],
    [ "mapView:didZoomAnimated:gesture:", "protocol_q_map_view_delegate-p.html#aa2a22570087187f3007894678536f24b", null ],
    [ "mapView:gestureDidEnd:", "protocol_q_map_view_delegate-p.html#ac98829e231b3e899dba0af978ada16a0", null ],
    [ "mapView:gestureDidTrigger:", "protocol_q_map_view_delegate-p.html#a03b70367eea3482ac960097a741b87bd", null ],
    [ "mapView:markerOverlay:didChangeDragState:fromOldState:", "protocol_q_map_view_delegate-p.html#add617a25372748dd3f81cf56fea504b6", null ],
    [ "mapView:regionDidChangeAnimated:gesture:", "protocol_q_map_view_delegate-p.html#ada5f7c95b500eaabfd8591f900b41265", null ],
    [ "mapView:regionWillChangeAnimated:gesture:", "protocol_q_map_view_delegate-p.html#a1b18cb794f5ae1ff607d088035504337", null ],
    [ "mapView:scaleViewChanged:", "protocol_q_map_view_delegate-p.html#a92e733eeae2d4236d858d5b1b9fbace6", null ],
    [ "mapView:viewForAnnotation:", "protocol_q_map_view_delegate-p.html#a51b87e5ee650c0f821b29b2224909af6", null ],
    [ "mapView:viewForOverlay:", "protocol_q_map_view_delegate-p.html#abcdb7949f27a7939766db79e7b4813ca", null ],
    [ "mapView:willMoveAnimated:gesture:", "protocol_q_map_view_delegate-p.html#a00c61e780381b20d8abbc0e339f2ed58", null ],
    [ "mapView:willZoomAnimated:gesture:", "protocol_q_map_view_delegate-p.html#acc118ca98f5eac0392c5285f60685926", null ],
    [ "mapViewAuthentication:didFailWithError:", "protocol_q_map_view_delegate-p.html#a5f17a6bc3f3c7c8e4c7fb29f8681cb62", null ],
    [ "mapViewAuthenticationDidComplete:", "protocol_q_map_view_delegate-p.html#a13808a360a53a8f01c0509c81ef17eb9", null ],
    [ "mapViewDidFailLoadingMap:withError:", "protocol_q_map_view_delegate-p.html#a0f3d4bab85921ce3b55be387601f14c5", null ],
    [ "mapViewDidStopLocatingUser:", "protocol_q_map_view_delegate-p.html#a23b18221aa932555bee3f04cd9c238bc", null ],
    [ "mapViewDrawFrame:", "protocol_q_map_view_delegate-p.html#ab90001fd4a145e3a0ead65b89042acd6", null ],
    [ "mapViewFirstRenderDidComplete:", "protocol_q_map_view_delegate-p.html#ac1f389b45c9edb21784e6590e93f3b9b", null ],
    [ "mapViewInitComplete:", "protocol_q_map_view_delegate-p.html#a5f5afa7afba06eed440d314655b8119e", null ],
    [ "mapViewLogger:logMessage:", "protocol_q_map_view_delegate-p.html#a875a00550983e78d5ee46cea1ed1c35e", null ],
    [ "mapViewRegionChange:", "protocol_q_map_view_delegate-p.html#a21588e52511d9497782dc3731d8a22af", null ],
    [ "mapViewStatusChangesCompleted:", "protocol_q_map_view_delegate-p.html#aa99772768909853b71d653eee61731bb", null ],
    [ "mapViewWillStartLocatingUser:", "protocol_q_map_view_delegate-p.html#a69b0dd1a27e7c4d81dab03198391503f", null ]
];

==> TencentMapSDK_iOS_3D_v6.7.0.zip: html/protocol_q_map_view_delegate-p.js <==
var protocol_q_map_view_delegate_p =
[
    [ "locationManagerDidChangeAuthorization:", "protocol_q_map_view_delegate-p.html#ae05ae20c1c451ae46bbf17c1fa041bad", null ],
    [ "mapUpdateFinished:", "protocol_q_map_view_delegate-p.html#ada2dcef0bc352b7a08c0c016174e647a", null ],
    [ "mapView:annotationView:calloutAccessoryControlTapped:", "protocol_q_map_view_delegate-p.html#addc6778f9d1536b431066d14184dd3ee", null ],
    [ "mapView:annotationView:collidedViewsDidHide:", "protocol_q_map_view_delegate-p.html#a154869a9351385b58c38802c07923cd5", null ],
    [ "mapView:annotationView:collidedViewsDidShow:", "protocol_q_map_view_delegate-p.html#ad50638743d3e7dd71db4e4ed4cf3c773", null ],
    [ "mapView:annotationView:didChangeDragState:fromOldState:", "protocol_q_map_view_delegate-p.html#a9ee4627234450c4a728af6216cddca9b", null ],
    [ "mapView:annotationViewCalloutTapped:", "protocol_q_map_view_delegate-p.html#a04e22a4d9bd72c10e8c6f3be1440cd7c", null ],
    [ "mapView:customCalloutForAnnotationView:", "protocol_q_map_view_delegate-p.html#af1ad6c0ad59e863c65a9c3e037ea60f4", null ],
    [ "mapView:didAddAnnotationViews:", "protocol_q_map_view_delegate-p.html#ad23a7ea97bde36822c7a1633ccd68e26", null ],
    [ "mapView:didAddOverlayViews:", "protocol_q_map_view_delegate-p.html#a80f0a2693fb0c8edced25805037f13bd", null ],
    [ "mapView:didAnnotationViewTapped:", "protocol_q_map_view_delegate-p.html#abe7ad61a355ba6abe7b70156bdbb1a41", null ],
    [ "mapView:didChangeUserTrackingMode:animated:", "protocol_q_map_view_delegate-p.html#a187da22432616cb02f4c074c21f4f2a8", null ],
    [ "mapView:didDeselectAnnotationView:", "protocol_q_map_view_delegate-p.html#ad500838cdd3f744fa393a7cc3c69bd9d", null ],
    [ "mapView:didFailToLocateUserWithError:", "protocol_q_map_view_delegate-p.html#aaf54cbaa96411ed613553a316e4f30ae", null ],
    [ "mapView:didMoveAnimated:gesture:", "protocol_q_map_view_delegate-p.html#a084ca8d89c79d8dbb0536ad148d63662", null ],
    [ "mapView:didSelectAnnotationView:", "protocol_q_map_view_delegate-p.html#a62fdf8aa5a7aef763b125c998eaf8964", null ],
    [ "mapView:didTapAtCoordinate:", "protocol_q_map_view_delegate-p.html#a980880cd3da3156540ba0a69855ce477", null ],
    [ "mapView:didTapMarkerOverlayCallout:", "protocol_q_map_view_delegate-p.html#acfd18e33e5bc42997b987693a2468fa3", null ],
    [ "mapView:didTapMyLocation:", "protocol_q_map_view_delegate-p.html#a5ba6df7eef363f7d31b036e167d2aec1", null ],
    [ "mapView:didTapOverlay:", "protocol_q_map_view_delegate-p.html#a3a5e63eb5525ca332ab13d50c545ed1d", null ],
    [ "mapView:didTapOverlay:coordinate:", "protocol_q_map_view_delegate-p.html#ac48a37ffc5259cece81e03cd94199092", null ],
    [ "mapView:didTapPoi:", "protocol_q_map_view_delegate-p.html#a6fa4fcb119acfb63b82f12d94d921d31", null ],
    [ "mapView:didUpdateUserLocation:fromHeading:", "protocol_q_map_view_delegate-p.html#a2727ba05ddc465b2bf8dda886b99a960", null ],
    [ "mapView:didZoomAnimated:gesture:", "protocol_q_map_view_delegate-p.html#aa2a22570087187f3007894678536f24b", null ],
    [ "mapView:gestureDidEnd:", "protocol_q_map_view_delegate-p.html#ac98829e231b3e899dba0af978ada16a0", null ],
    [ "mapView:gestureDidTrigger:", "protocol_q_map_view_delegate-p.html#a03b70367eea3482ac960097a741b87bd", null ],
    [ "mapView:markerOverlay:didChangeDragState:fromOldState:", "protocol_q_map_view_delegate-p.html#add617a25372748dd3f81cf56fea504b6", null ],
    [ "mapView:regionDidChangeAnimated:gesture:", "protocol_q_map_view_delegate-p.html#ada5f7c95b500eaabfd8591f900b41265", null ],
    [ "mapView:regionWillChangeAnimated:gesture:", "protocol_q_map_view_delegate-p.html#a1b18cb794f5ae1ff607d088035504337", null ],
    [ "mapView:scaleViewChanged:", "protocol_q_map_view_delegate-p.html#a92e733eeae2d4236d858d5b1b9fbace6", null ],
    [ "mapView:viewForAnnotation:", "protocol_q_map_view_delegate-p.html#a51b87e5ee650c0f821b29b2224909af6", null ],
    [ "mapView:viewForOverlay:", "protocol_q_map_view_delegate-p.html#abcdb7949f27a7939766db79e7b4813ca", null ],
    [ "mapView:willMoveAnimated:gesture:", "protocol_q_map_view_delegate-p.html#a00c61e780381b20d8abbc0e339f2ed58", null ],
    [ "mapView:willZoomAnimated:gesture:", "protocol_q_map_view_delegate-p.html#acc118ca98f5eac0392c5285f60685926", null ],
    [ "mapViewAuthentication:didFailWithError:", "protocol_q_map_view_delegate-p.html#a5f17a6bc3f3c7c8e4c7fb29f8681cb62", null ],
    [ "mapViewAuthenticationDidComplete:", "protocol_q_map_view_delegate-p.html#a13808a360a53a8f01c0509c81ef17eb9", null ],
    [ "mapViewDidFailLoadingMap:withError:", "protocol_q_map_view_delegate-p.html#a0f3d4bab85921ce3b55be387601f14c5", null ],
    [ "mapViewDidMoveToCameraRestricted:", "protocol_q_map_view_delegate-p.html#acfcc98b925faf2f943527a2868cb1912", null ],
    [ "mapViewDidStopLocatingUser:", "protocol_q_map_view_delegate-p.html#a23b18221aa932555bee3f04cd9c238bc", null ],
    [ "mapViewDrawFrame:", "protocol_q_map_view_delegate-p.html#ab90001fd4a145e3a0ead65b89042acd6", null ],
    [ "mapViewFirstRenderDidComplete:", "protocol_q_map_view_delegate-p.html#ac1f389b45c9edb21784e6590e93f3b9b", null ],
    [ "mapViewInitComplete:", "protocol_q_map_view_delegate-p.html#a5f5afa7afba06eed440d314655b8119e", null ],
    [ "mapViewLogger:logMessage:", "protocol_q_map_view_delegate-p.html#a875a00550983e78d5ee46cea1ed1c35e", null ],
    [ "mapViewRegionChange:", "protocol_q_map_view_delegate-p.html#a21588e52511d9497782dc3731d8a22af", null ],
    [ "mapViewStatusChangesCompleted:", "protocol_q_map_view_delegate-p.html#aa99772768909853b71d653eee61731bb", null ],
    [ "mapViewWillStartLocatingUser:", "protocol_q_map_view_delegate-p.html#a69b0dd1a27e7c4d81dab03198391503f", null ]
];
